@@ -65,12 +65,12 @@ def handle_error(func):
         try:
             return func(*args, **kwargs)
         except BaiduPCSError as err:
-            print(f"[bold red]ERROR[/bold red]: BaiduPCSError: {err}")
+            print(f"(v{__version__}) [bold red]ERROR[/bold red]: BaiduPCSError: {err}")
             if DEBUG:
                 console = Console()
                 console.print_exception()
         except Exception as err:
-            print(f"[bold red]System ERROR[/bold red]: {err}")
+            print(f"(v{__version__}) [bold red]System ERROR[/bold red]: {err}")
             if DEBUG:
                 console = Console()
                 console.print_exception()
@@ -149,7 +149,7 @@ _APP_DOC = f"""BaiduPCS App v{__version__}
 
     \b
     如果第一次使用，你需要运行 `BaiduPCS-Py useradd` 添加 `bduss` 和 `cookies`。
-    如何获取 `bduss` 和 `cookies` 见 https://github.com/PeterDing/BaiduPCS-Py#useradd
+    如何获取 `bduss` 和 `cookies` 见 https://github.com/PeterDing/BaiduPCS-Py#%E6%B7%BB%E5%8A%A0%E7%94%A8%E6%88%B7
     用 `BaiduPCS-Py {{command}} --help` 查看具体的用法。"""
 
 _ALIAS_DOC = "Command 别名:\n\n\b\n" + "\n".join(
@@ -170,28 +170,6 @@ def app(ctx, account_data):
 # {{{
 
 
-@app.command()
-@click.argument("remotedir", type=str, default="/", required=False)
-@click.pass_context
-@handle_error
-def cd(ctx, remotedir):
-    """切换工作目录"""
-
-    am = ctx.obj.account_manager
-    am.cd(remotedir)
-    am.save()
-
-
-@app.command()
-@click.pass_context
-@handle_error
-def pwd(ctx):
-    """显示工作目录"""
-
-    pwd = _pwd(ctx)
-    print(pwd)
-
-
 @app.command()
 @click.argument("user_id", type=int, default=None, required=False)
 @click.pass_context
@@ -306,6 +284,28 @@ def userdel(ctx):
     print(f"Delete user {user_id}")
 
 
+@app.command()
+@click.argument("remotedir", type=str, default="/", required=False)
+@click.pass_context
+@handle_error
+def cd(ctx, remotedir):
+    """切换当前工作目录"""
+
+    am = ctx.obj.account_manager
+    am.cd(remotedir)
+    am.save()
+
+
+@app.command()
+@click.pass_context
+@handle_error
+def pwd(ctx):
+    """显示当前工作目录"""
+
+    pwd = _pwd(ctx)
+    print(pwd)
+
+
 # }}}
 
 # Files
@@ -607,7 +607,7 @@ def remove(ctx, remotepaths):
     help="""指定下载应用
 
     \b
-    默认为 me (BaiduPCS-Py 自己的下载器，不支持断续下载)
+    默认为 me (BaiduPCS-Py 自己的下载器，支持断续下载)
         me 使用多文件并发下载。
 
     除 me 外，其他下载器，不使用多文件并发下载，使用一个文件多链接下载。
@@ -878,7 +878,7 @@ def cancelshared(ctx, share_ids):
 @click.argument("shared_url", nargs=1, type=str)
 @click.argument("remotedir", nargs=1, type=str)
 @click.option("--password", "-p", type=str, help="链接密码，如果没有不用设置")
-@click.option("--no-show-vcode", "--NV", is_flag=True)
+@click.option("--no-show-vcode", "--NV", is_flag=True, help="不显示验证码")
 @click.pass_context
 @handle_error
 def save(ctx, shared_url, remotedir, password, no_show_vcode):
