@@ -3,6 +3,6 @@ from threading import Semaphore
 
 def sure_release(semaphore: Semaphore, func, *args, **kwargs):
     try:
-        func(*args, **kwargs)
+        return func(*args, **kwargs)
     finally:
         semaphore.release()
